# `Finic`

Finic.ai is a platform for deploying integrations and workflow automations in Python. This is the Python client for Finic

## Contributing

To run locally, run:

```
python3 setup.py sdist bdist_wheel
pip install /path/to/folder/dist/finic-py-0.1.0.tar.gz
```
